pub struct IssueAccessTokenRequest {
pub id: AccessTokenId,
pub expires_at: Option<OffsetDateTime>,
pub auto_prefix_streams: Option<bool>,
pub scope: AccessTokenScope,
}Fields
id: AccessTokenIdAccess token ID. It must be unique to the account and between 1 and 96 bytes in length.
expires_at: Option<OffsetDateTime>Expiration time in RFC 3339 format. If not set, the expiration will be set to that of the requestor’s token.
auto_prefix_streams: Option<bool>Namespace streams based on the configured stream-level scope, which must be a prefix. Stream name arguments will be automatically prefixed, and the prefix will be stripped when listing streams.
scope: AccessTokenScopeAccess token scope.