#[non_exhaustive]pub enum ErrorCode {
Show 27 variants
AccessTokenNotFound,
Authn,
BadFrame,
BadHeader,
BadJson,
BadPath,
BadProto,
BadQuery,
BasinDeletionPending,
BasinNotFound,
ClientHangup,
DecryptionFailed,
HotServer,
Invalid,
NotImplemented,
Other,
PermissionDenied,
QuotaExhausted,
RateLimited,
RequestTimeout,
ResourceAlreadyExists,
Storage,
StreamDeletionPending,
StreamNotFound,
TransactionConflict,
Unavailable,
UpstreamTimeout,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccessTokenNotFound
Authn
BadFrame
BadHeader
BadJson
BadPath
BadProto
BadQuery
BasinDeletionPending
BasinNotFound
ClientHangup
DecryptionFailed
HotServer
Invalid
NotImplemented
Other
PermissionDenied
QuotaExhausted
RateLimited
RequestTimeout
ResourceAlreadyExists
Storage
StreamDeletionPending
StreamNotFound
TransactionConflict
UpstreamTimeout
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub fn is_auth_error(self) -> bool
pub fn is_auth_error(self) -> bool
Whether this code represents an authentication or authorization failure.
Sourcepub fn status(self) -> StatusCode
pub fn status(self) -> StatusCode
HTTP status associated with this error code.
Sourcepub fn is_retryable(self) -> bool
pub fn is_retryable(self) -> bool
Whether retrying an operation that returned this code is sensible.
Sourcepub fn has_no_side_effects(self) -> bool
pub fn has_no_side_effects(self) -> bool
Whether the server guarantees that an operation returning this code had no side effects.